==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/QGpGuiTools/src/LoopProgressWidget.h <==
/***************************************************************************
**
**  This file is part of QGpGuiTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-09-18
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef LOOPPROGRESSWIDGET_H
#define LOOPPROGRESSWIDGET_H

#include <QtGui>
#if(QT_VERSION > QT_VERSION_CHECK(5, 0, 0))
#include <QtWidgets>
#endif

#include <QGpCoreTools.h>

#include "QGpGuiToolsDLLExport.h"

namespace QGpGuiTools {

class QGPGUITOOLS_EXPORT LoopProgressWidget : public QScrollArea
{
  Q_OBJECT
public:
  LoopProgressWidget(QWidget *parent=nullptr);
  ~LoopProgressWidget();

  void setLoop(const ParallelLoop * loop);
private slots:
  void setStatus(int processIndex, QString msg);
  void setProgress(int processIndex, int value);
  void initProgress(int processIndex, int maximumValue);
  void stopAutoScroll();
private:
  QList<QLabel *> _labelList;
  QList<QProgressBar *> _progressList;
  QVBoxLayout * _layout;
  bool _autoScroll;
};

} // namespace QGpGuiTools

#endif // LOOPPROGRESSWIDGET_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/QGpGuiTools/src/LoopProgressWidget.h <==
/***************************************************************************
**
**  This file is part of QGpGuiTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-09-18
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef LOOPPROGRESSWIDGET_H
#define LOOPPROGRESSWIDGET_H

#include <QtGui>
#if(QT_VERSION > QT_VERSION_CHECK(5, 0, 0))
#include <QtWidgets>
#endif

#include <QGpCoreTools.h>

#include "QGpGuiToolsDLLExport.h"

namespace QGpGuiTools {

class QGPGUITOOLS_EXPORT LoopProgressWidget : public QWidget
{
  Q_OBJECT
public:
  LoopProgressWidget(QWidget *parent=nullptr);
  ~LoopProgressWidget();

  void setLoop(const ParallelLoop * loop);
  void setButtons(QToolButton * start, QToolButton * stop);
  void setRunning(bool r, const QString& message=QString());
private slots:
  void start();
  void setStatus(int processIndex, QString msg);
  void setProgress(int processIndex, int value);
  void initProgress(int processIndex, int maximumValue);
  void stopAutoScroll();
signals:
  void startJobs(int threadCount);
private:
  QLabel * _message;
  QScrollArea * _area;
  QToolButton * _start, * _stop;

  QList<QLabel *> _labelList;
  QList<QProgressBar *> _progressList;
  QVBoxLayout * _layout;
  bool _autoScroll;
};

} // namespace QGpGuiTools

#endif // LOOPPROGRESSWIDGET_H
